Struct wasmcloud_interface_httpserver::HttpRequest [−][src]
pub struct HttpRequest {
pub method: String,
pub path: String,
pub query_string: String,
pub header: HeaderMap,
pub body: Vec<u8>,
}Expand description
HttpRequest contains data sent to actor about the http request
Fields
method: StringHTTP method. One of: GET,POST,PUT,DELETE,HEAD,OPTIONS,CONNECT,PATCH,TRACE
path: Stringfull request path
query_string: Stringquery string. May be an empty string if there were no query parameters.
header: HeaderMapmap of request headers (string key, string value)
body: Vec<u8>Request body as a byte array. May be empty.